import type { Actions, Node, SourceNodesArgs } from "gatsby";
import type { IContentfulAsset, IContentfulEntry, IContentfulLink, ILocalizedField, IEntryWithAllLocalesAndWithoutLinkResolution } from "./types/contentful";
import type { SyncCollection, Asset, ContentType, Space, Locale, LocaleCode, FieldsType, EntrySkeletonType, DeletedEntry } from "contentful";
import type { IProcessedPluginOptions } from "./types/plugin";
export declare const makeTypeName: (type: string, typePrefix?: string) => string;
interface IContententfulLocaleFallback {
    [key: string]: LocaleCode;
}
export declare const getLocalizedField: <T>({ field, locale, localesFallback, }: {
    field: ILocalizedField;
    locale: Locale;
    localesFallback: IContententfulLocaleFallback;
}) => T | null;
export declare const buildFallbackChain: (locales: Array<Locale>) => IContententfulLocaleFallback;
export declare const makeId: ({ spaceId, id, currentLocale, defaultLocale, type, }: {
    spaceId: string;
    id: string;
    currentLocale: string;
    defaultLocale: string;
    type: string;
}) => string;
export declare const createRefId: (node: IEntryWithAllLocalesAndWithoutLinkResolution<FieldsType, string> | IContentfulEntry | Asset, spaceId: string) => string;
export declare const createLinkRefId: (link: IContentfulLink, spaceId: string) => string;
export declare const buildEntryList: ({ contentTypeItems, currentSyncData, }: {
    contentTypeItems: Array<ContentType>;
    currentSyncData: SyncCollection<EntrySkeletonType, "WITH_ALL_LOCALES" | "WITHOUT_LINK_RESOLUTION">;
}) => Array<Array<IEntryWithAllLocalesAndWithoutLinkResolution<FieldsType, string>>>;
export declare const buildResolvableSet: ({ entryList, existingNodes, assets, spaceId, }: {
    entryList: Array<Array<IEntryWithAllLocalesAndWithoutLinkResolution<FieldsType, string>>>;
    existingNodes: Map<string, IContentfulEntry>;
    assets: Array<Asset>;
    spaceId: string;
}) => Set<string>;
interface IForeignReference {
    name: string;
    id: string;
    spaceId: string;
    type: string;
}
interface IForeignReferenceMap {
    [key: string]: Array<IForeignReference>;
}
interface IForeignReferenceMapState {
    links: {
        [key: string]: Array<string>;
    };
    backLinks: IForeignReferenceMap;
}
export declare const buildForeignReferenceMap: ({ contentTypeItems, entryList, resolvable, defaultLocale, space, useNameForId, contentTypePrefix, previousForeignReferenceMapState, deletedEntries, }: {
    contentTypeItems: Array<ContentType>;
    entryList: Array<Array<IEntryWithAllLocalesAndWithoutLinkResolution<FieldsType, string>>>;
    resolvable: Set<string>;
    defaultLocale: string;
    space: Space;
    useNameForId: boolean;
    contentTypePrefix: string;
    previousForeignReferenceMapState?: IForeignReferenceMapState | undefined;
    deletedEntries: Array<DeletedEntry>;
    createNodeId: any;
}) => IForeignReferenceMapState;
interface ICreateNodesForContentTypeArgs extends Omit<Actions, "createNode">, SourceNodesArgs {
    contentTypeItem: ContentType;
    entries: Array<IEntryWithAllLocalesAndWithoutLinkResolution<FieldsType, string>>;
    resolvable: Set<string>;
    foreignReferenceMap: IForeignReferenceMap;
    defaultLocale: string;
    locales: Array<Locale>;
    space: Space;
    useNameForId: boolean;
    pluginConfig: IProcessedPluginOptions;
    createNode: (node: Node) => void | Promise<void>;
}
export declare const createNodesForContentType: ({ contentTypeItem, entries, unstable_createNodeManifest, createNode, createNodeId, getNode, resolvable, foreignReferenceMap, defaultLocale, locales, space, useNameForId, pluginConfig, reporter, }: ICreateNodesForContentTypeArgs) => Promise<unknown>;
export declare const createAssetNodes: ({ assetItem, createNode, createNodeId, defaultLocale, locales, space, }: {
    assetItem: any;
    createNode: any;
    createNodeId: any;
    defaultLocale: any;
    locales: Array<Locale>;
    space: Space;
}) => Promise<Array<IContentfulAsset>>;
export {};
