"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.detectMarkdownField = detectMarkdownField;
exports.makeContentTypeIdMap = makeContentTypeIdMap;
exports.untilNextEventLoopTick = untilNextEventLoopTick;
var _normalize = require("./normalize");
// When iterating on tons of objects, we don't want to block the event loop
// this helper function returns a promise that resolves on the next tick so that the event loop can continue before we continue running blocking code
function untilNextEventLoopTick() {
  return new Promise(res => {
    setImmediate(() => {
      res(null);
    });
  });
}
function detectMarkdownField(field, contentTypeItem, enableMarkdownDetection, markdownFields) {
  let typeName = field.type;
  if (typeName == `Text` && enableMarkdownDetection) {
    typeName = `Markdown`;
  }

  // Detect markdown based on given field ids
  const markdownFieldDefinitions = markdownFields.get(contentTypeItem.sys.id);
  if (markdownFieldDefinitions && markdownFieldDefinitions.includes(field.id)) {
    typeName = `Markdown`;
  }
  return typeName;
}

// Establish identifier for content type based on plugin options
//  Use `name` if specified, otherwise, use internal id (usually a natural-language constant,
//  but sometimes a base62 uuid generated by Contentful, hence the option)
function makeContentTypeIdMap(contentTypeItems, contentTypePrefix, useNameForId) {
  const contentTypeIdMap = new Map();
  contentTypeItems.forEach(contentType => {
    let contentTypeItemId;
    if (useNameForId) {
      contentTypeItemId = (0, _normalize.makeTypeName)(contentType.name, contentTypePrefix);
    } else {
      contentTypeItemId = (0, _normalize.makeTypeName)(contentType.sys.id, contentTypePrefix);
    }
    contentTypeIdMap.set(contentType.sys.id, contentTypeItemId);
  });
  return contentTypeIdMap;
}